pub struct Set<T: Obj>(/* private fields */);Expand description
Garbage-collected hash set implementing Copy.
This implements Ord but the order is not meaningful; this is just so one can use BTreeMaps.
In particular, the order might differ across two runs of the same program.
Implementations